@@ -12,6 +12,9 @@ const (
 	AutoVariablesExtension = ".auto.spvars"
 	JsonExtension          = ".json"
 	CsvExtension           = ".csv"
+	TextExtension          = ".txt"
+	SnapshotExtension      = ".sps"
+	TokenExtension         = ".sptt"
 )
 
 var YamlExtensions = []string{".yml", ".yaml"}
