@@ -14,9 +14,9 @@ import (
 	"github.com/turbot/steampipe/pkg/constants/runtime"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/pluginmanager"
 	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/turbot/steampipe/pluginmanager"
 )
 
 // StopStatus is a pseudoEnum for service stop result
@@ -178,8 +178,7 @@ func StopServices(ctx context.Context, force bool, invoker constants.Invoker) (s
 func stopDBService(ctx context.Context, force bool) (StopStatus, error) {
 	if force {
 		// check if we have a process from another install-dir
-		statushooks.SetStatus(ctx, "Checking for running instances...")
-		defer statushooks.Done(ctx)
+		statushooks.SetStatus(ctx, "Checking for running instances…")
 		// do not use a context that can be cancelled
 		anyStopped := killInstanceIfAny(context.Background())
 		if anyStopped {
@@ -257,8 +256,7 @@ func doThreeStepPostgresExit(ctx context.Context, process *psutils.Process) erro
 		// process didn't quit
 
 		// set status, as this is taking time
-		statushooks.SetStatus(ctx, "Shutting down...")
-		defer statushooks.Done(ctx)
+		statushooks.SetStatus(ctx, "Shutting down…")
 
 		// try a SIGINT
 		err = process.SendSignal(syscall.SIGINT)
