@@ -26,6 +26,14 @@ func (vr *VersionCheckReport) ShortName() string {
 	return fmt.Sprintf("%s/%s", vr.CheckResponse.Org, vr.CheckResponse.Name)
 }
 
+func (vr *VersionCheckReport) ShortNameWithStream() string {
+	// dont show stream names for latest streams
+	if vr.CheckResponse.Stream != "latest" {
+		return fmt.Sprintf("%s/%s@%s", vr.CheckResponse.Org, vr.CheckResponse.Name, vr.CheckResponse.Stream)
+	}
+	return fmt.Sprintf("%s/%s", vr.CheckResponse.Org, vr.CheckResponse.Name)
+}
+
 // VersionChecker :: wrapper struct over the plugin version check utilities
 type VersionChecker struct {
 	pluginsToCheck []*versionfile.InstalledVersion
@@ -186,7 +194,7 @@ func (v *VersionChecker) requestServerForLatest(ctx context.Context, payload []v
 
 	bodyBytes, err := io.ReadAll(resp.Body)
 	if err != nil {
-		fmt.Printf("[TRACE] Error reading body stream")
+		log.Printf("[TRACE] Error reading body stream: %v", err)
 		return nil, err
 	}
 	defer resp.Body.Close()
