@@ -1,7 +1,7 @@
 package versionmap
 
 import (
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 )
 
 // VersionMap represents a map of semver versions, keyed by dependency name
